package net.knarcraft.permissionsigns.command;

import org.apache.commons.lang.ArrayUtils;
import org.bukkit.command.Command;
import org.bukkit.command.CommandSender;
import org.bukkit.command.TabCompleter;
import org.bukkit.entity.Player;
import org.jetbrains.annotations.NotNull;

import java.util.ArrayList;
import java.util.List;

/**
 * The tab completer for this plugin's main command
 */
public class PermissionSignsTabCompleter implements TabCompleter {

    @Override
    public List<String> onTabComplete(@NotNull CommandSender sender, @NotNull Command command, @NotNull String alias, @NotNull String[] args) {
        if (args.length == 1) {
            List<String> commands = getAvailableCommands(sender);
            List<String> matchingCommands = new ArrayList<>();
            for (String availableCommand : commands) {
                if (availableCommand.startsWith(args[0])) {
                    matchingCommands.add(availableCommand);
                }
            }
            return matchingCommands;
        } else if (args.length > 1 && args[0].equalsIgnoreCase("create")) {
            String[] subArgs = (String[]) ArrayUtils.remove(args, 0);
            return new CreateTabCompleter().onTabComplete(sender, command, alias, subArgs);
        } else {
            return new ArrayList<>();
        }
    }

    /**
     * Gets the available commands
     *
     * @param commandSender <p>The command sender to get available commands for</p>
     * @return <p>The commands available to the command sender</p>
     */
    private List<String> getAvailableCommands(CommandSender commandSender) {
        List<String> commands = new ArrayList<>();
        commands.add("about");
        if (!(commandSender instanceof Player player) || player.hasPermission("permissionsigns.admin.reload")) {
            commands.add("reload");
        }
        if (commandSender instanceof Player player && player.hasPermission("permissionsigns.admin.create")) {
            commands.add("create");
            commands.add("cancel");
        }
        return commands;
    }

}
