package net.knarcraft.permissionsigns.formatting;

/**
 * An enum representing all translatable messages
 */
public enum TranslatableMessage {

    /**
     * The prefix to display in messages
     */
    PREFIX,

    /**
     * The prefix to display on signs
     */
    SIGN_PREFIX,

    /**
     * The text to display for 1 second
     */
    UNIT_SECOND,

    /**
     * The text to display for a number of seconds
     */
    UNIT_SECONDS,

    /**
     * The text to display for 1 minute
     */
    UNIT_MINUTE,

    /**
     * The text to display for a number of minutes
     */
    UNIT_MINUTES,

    /**
     * The text to display for 1 hour
     */
    UNIT_HOUR,

    /**
     * The text to display for a number of hours
     */
    UNIT_HOURS,

    /**
     * The text to display for 1 day
     */
    UNIT_DAY,

    /**
     * The text to display for a number of days
     */
    UNIT_DAYS,

    /**
     * The text to display on a permission sign that is entirely free
     */
    SIGN_COST_FREE,

    /**
     * The text to display on a permissions sign whose permissions never expire
     */
    SIGN_PERMANENT,

    /**
     * The error message to display if the given cost is not a valid number
     */
    COST_INVALID_NUMBER,

    /**
     * The error message to display if the given duration is not a valid number
     */
    DURATION_INVALID_NUMBER,

    /**
     * The error message to display if a player-only command is executed from the console
     */
    COMMAND_PLAYER_ONLY,

    /**
     * The error message to display if a player attempts to break a permission sign without the necessary permissions
     */
    PERMISSION_SIGN_DESTROY_DENY,

    /**
     * The message to display to a non-sneaking player trying to destroy a permissions sign
     */
    PERMISSION_SIGN_DESTROY_SNEAK,

    /**
     * The error message to display if the user has not provided necessary information to create a permission sign
     */
    MISSING_CREATION_INFO,

    /**
     * The error message to be displayed when a player is denied from executing a command
     */
    COMMAND_PERMISSION_DENIED,

    /**
     * The message to be displayed when a player successfully destroys a permissions sign
     */
    PERMISSION_SIGN_REMOVED,

    /**
     * The message displayed when a player has successfully used the /ps create command
     */
    CREATION_REQUEST_CREATED,

    /**
     * The message displayed when a creation request is manually cancelled
     */
    CREATION_REQUEST_CANCELLED,

    /**
     * The message to display if a player is unable to pay for using a permission sign
     */
    CANNOT_AFFORD,

    /**
     * The message to display is a player has all permissions given by a permission sign
     */
    ALREADY_HAS_PERMISSIONS,

    /**
     * The message to display when a permission sign successfully grants permissions to the player
     */
    PERMISSIONS_GRANTED,

    /**
     * The message to display when a permission sign successfully grants permissions to the player permanently
     */
    PERMISSIONS_GRANTED_PERMANENTLY,

    /**
     * The message to display if a player has specified an invalid world to set a permission for
     */
    PERMISSION_WORLD_INVALID,

    /**
     * The message to display if a player is missing the permission required for interacting with permission signs
     */
    INTERACT_PERMISSION_MISSING,

    /**
     * The message to display when a permission sign has been successfully created
     */
    PERMISSION_SIGN_CREATED,

    /**
     * The message to display when a reload action has been successfully performed
     */
    RELOAD_SUCCESSFUL,

    /**
     * The text describing all properties of a permission sign
     */
    SIGN_INFO

}
